summaryrefslogtreecommitdiff
path: root/src/ai/ai_core.cpp
diff options
context:
space:
mode:
authortruebrain <truebrain@openttd.org>2009-01-13 01:46:46 +0000
committertruebrain <truebrain@openttd.org>2009-01-13 01:46:46 +0000
commitbcbbf2c366b829994983513d2858762874e99964 (patch)
treea2e699a90fbe7d2ebd18ddd9ea713546f3f641bc /src/ai/ai_core.cpp
parente6883c5cc7dedad23dfcf7a303a7154520db7f5e (diff)
downloadopenttd-bcbbf2c366b829994983513d2858762874e99964.tar.xz
(svn r15045) -Add [NoAI API CHANGE]: in info.nut you can now have (optional) a CanLoadFromVersion(version), which should return true/false, to indicate if you can load a savegame made with your AI of version 'version'
-Add [NoAI API CHANGE]: in main.nut the Load() function now should be Load(version, data), where 'version' is the version of your AI which made the savegame -Codechange [NoAI]: various of function renames to make things more sane -Add [NoAI]: push the 'version' of the AI through various of layers -Codechange [NoAI]: various of code cleanups -Add [NoAI]: store the version of the AI in the savegame too
Diffstat (limited to 'src/ai/ai_core.cpp')
-rw-r--r--src/ai/ai_core.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/ai/ai_core.cpp b/src/ai/ai_core.cpp
index f0a82f771..3d8fc7707 100644
--- a/src/ai/ai_core.cpp
+++ b/src/ai/ai_core.cpp
@@ -211,7 +211,7 @@ void CcAI(bool success, TileIndex tile, uint32 p1, uint32 p2)
}
}
/* static */ void AI::Load(CompanyID company)
{
if (!_networking || _network_server) {
assert(IsValidCompanyID(company));
@@ -219,7 +219,7 @@ void CcAI(bool success, TileIndex tile, uint32 p1, uint32 p2)
CompanyID old_company = _current_company;
_current_company = company;
- GetCompany(company)->ai_instance->Load();
+ GetCompany(company)->ai_instance->Load(version);
_current_company = old_company;
} else {
/* Read, but ignore, the load data */
@@ -237,9 +237,9 @@ void CcAI(bool success, TileIndex tile, uint32 p1, uint32 p2)
return AI::ai_scanner->GetAIInfoList();
}
/* static */ AIInfo *AI::GetCompanyInfo(const char *name)
{
- return AI::ai_scanner->FindAI(name);
+ return AI::ai_scanner->FindInfo(name, version);
}
/* static */ bool AI::ImportLibrary(const char *library, const char *class_name, int version, HSQUIRRELVM vm)
@@ -211,7 +211,7 @@ void CcAI(bool success, TileIndex tile, uint32 p1, uint32 p2)
}
}
-/* static */ void AI::Load(CompanyID company)
+/* static */ void AI::Load(CompanyID company, int version)
{
if (!_networking || _network_server) {
@@ -237,9 +237,9 @@ void CcAI(bool success, TileIndex tile, uint32 p1, uint32 p2)
return AI::ai_scanner->GetAIInfoList();
}
-/* static */ AIInfo *AI::GetCompanyInfo(const char *name)
+/* static */ AIInfo *AI::FindInfo(const char *name, int version)
{